#pragma once
typedef struct {
	PyObject_HEAD
	PyObject* NxDATE_DST_UNKNOWN					;
	PyObject* NxDATE_DST_ON							;
	PyObject* NxDATE_DST_OFF						;
	PyObject* NxDATE_DST_ONTODAY					;
	PyObject* NxDATE_DST_OFFTODAY					;
	PyObject* NxDOW_SUNDAY							;
	PyObject* NxDOW_MONDAY							;
	PyObject* NxDOW_TUESDAY							;
	PyObject* NxDOW_WEDNESDAY						;
	PyObject* NxDOW_THURSDAY						;
	PyObject* NxDOW_FRIDAY							;
	PyObject* NxDOW_SATURDAY						;
	PyObject* NxCLOCK_NOCHANGE						;
	PyObject* NxCLOCK_CLOCK							;
	PyObject* NxCLOCK_SECOND						;
	PyObject* NxCLOCK_MINUTE						;
	PyObject* NxCLOCK_HOUR							;
	PyObject* NxCORESTATUS_RUNNING					;
	PyObject* NxCORESTATUS_INITIALIZING				;
	PyObject* NxCORESTATUS_COMPLETE					;
	PyObject* NxCORESTATUS_SYNCHRONIZING			;
	PyObject* NxCORESTATUS_ERROR					;
	PyObject* NxCORESTATUS_WAITFORCOREACCESS		;
	PyObject* NxCORESTATUS_RESTARTING_TAPE			;
	PyObject* NxCORESTATUS_LOADED_STATE				;
	PyObject* NxCORESTATUS_SAVING_STATE				;
	PyObject* NxCORESTATUS_SYMBOLSPIN				;
	PyObject* NxCORESTATUS_TAPEOPEN					;
	PyObject* NxCSRUNMODE_SRC_DISK_FILE				;
	PyObject* NxCSRUNMODE_SRC_ACCESS_FILE			;
	PyObject* NxCSRUNMODE_SRC_ACCESS_MEMORY			;
	PyObject* NxCSRUNMODE_SRC_ACCESS_MB_OLDEST		;
	PyObject* NxCSRUNMODE_SRC_ACCESS_MB_LOWER		;
	PyObject* NxCSRUNMODE_SRC_ACCESS_MB_UPPER		;
	PyObject* NxCSRUNMODE_SRC_ACCESS_MB_SECOND		;
	PyObject* NxCSRUNMODE_SRC_ACCESS_MB_CURRENT		;
	PyObject* NxCSSAVESTATE_CAPTURE					;
	PyObject* NxCSSAVESTATE_COMPLETE				;
	PyObject* NxCSSAVESTATE_ERR_CREATEFILE			;
	PyObject* NxCSSAVESTATE_ERR_DISKSPACE			;
	PyObject* NxCSSAVESTATE_ERR_MEMORY				;
	PyObject* NxCSSYMBOLSPIN_STARTING				;
	PyObject* NxCSSYMBOLSPIN_COMPLETE				;
	PyObject* NxPERMID_REMOVE						;
	PyObject* NxQTE_NASDBIDTICK_NA					;
	PyObject* NxQTE_NASDBIDTICK_UP					;
	PyObject* NxQTE_NASDBIDTICK_DN					;
	PyObject* NxQTE_NASDBIDTICK_NO					;
	PyObject* NxQTE_REFRESH_REALTIME				;
	PyObject* NxQTE_REFRESH_SOURCE					;
	PyObject* NxQTE_REFRESH_MISMATCH				;
	PyObject* NxQTE_REFRESH_SYNCHRONIZE				;
	PyObject* NxBBOCHANGE_BIDEXG					;
	PyObject* NxBBOCHANGE_BIDPRICE					;
	PyObject* NxBBOCHANGE_BIDSIZE					;
	PyObject* NxBBOCHANGE_ASKEXG					;
	PyObject* NxBBOCHANGE_ASKPRICE					;
	PyObject* NxBBOCHANGE_ASKSIZE					;
	PyObject* NxMMT_UNKNOWN							;
	PyObject* NxMMT_REGULAR							;
	PyObject* NxMMT_PRIMARY							;
	PyObject* NxMMT_PASSIVE							;
	PyObject* NxMMQT_UNKNOWN						;
	PyObject* NxMMQT_REGULAR						;
	PyObject* NxMMQT_PASSIVE						;
	PyObject* NxMMQT_SYNDICATE						;
	PyObject* NxMMQT_PRESYNDICATE					;
	PyObject* NxMMQT_PENALTY						;
	PyObject* NxTPF_SETLAST							;
	PyObject* NxTPF_SETHIGH							;
	PyObject* NxTPF_SETLOW							;
	PyObject* NxTPF_SETOPEN							;
	PyObject* NxTPF_EXGINSERT						;
	PyObject* NxTPF_EXGCANCEL						;
	PyObject* NxTPF_SETTLEMENT						;
	PyObject* NxTCF_NOLAST							;
	PyObject* NxTCF_NOHIGH							;
	PyObject* NxTCF_NOLOW							;
	PyObject* NxTVT_INCRVOL							;
	PyObject* NxTVT_NONINCRVOL						;
	PyObject* NxTVT_TOTALVOL						;
	PyObject* NxTVT_TOTALVOLx100					;
	PyObject* NxRTA_SIGHL_EQ						;
	PyObject* NxRTA_SIGHL_LOWEST					;
	PyObject* NxRTA_SIGHL_LOW						;
	PyObject* NxRTA_SIGHL_HIGH						;
	PyObject* NxRTA_SIGHL_HIGHEST					;
	PyObject* NxRTA_QMTYPE_NONE						;
	PyObject* NxRTA_QMTYPE_BID						;
	PyObject* NxRTA_QMTYPE_ASK						;
	PyObject* NxRTA_QMTYPE_INSIDE					;
	PyObject* NxRTA_QMTYPE_BELOWBID					;
	PyObject* NxRTA_QMTYPE_ABOVEASK					;
	PyObject* NxRTA_QTEMATCHFLAG_OLDER				;
	PyObject* NxRTA_QTEMATCHFLAG_CROSSED			;
	PyObject* NxCFT_UNKNOWN							;
	PyObject* NxCFT_64BIT							;
	PyObject* NxCFT_32BIT							;
	PyObject* NxCFT_STRINGZ							;
	PyObject* NxCFT_DOUBLE							;
	PyObject* NxCFT_PRICE							;
	PyObject* NxCFT_DATE							;
	PyObject* NxCFT_TIME							;
	PyObject* NxCFT_NxSTRING						;
	PyObject* NxCFT_STRING_IDX						;
	PyObject* NxCFT_STRING_MAP						;
	PyObject* NxSS_ADD								;
	PyObject* NxSS_DEL								;
	PyObject* NxSS_MOD								;
	PyObject* NxSPIN_ALL_EXGS						;
	PyObject* NxSPIN_NON_OPTIONS					;
	PyObject* NxSPIN_OPTIONS						;
	PyObject* NxMSG_STATUS							;
	PyObject* NxMSG_EXGQUOTE						;
	PyObject* NxMSG_MMQUOTE							;
	PyObject* NxMSG_TRADE							;
	PyObject* NxMSG_CATEGORY						;
	PyObject* NxMSG_SYMBOLCHANGE					;
	PyObject* NxMSG_SYMBOLSPIN						;
	PyObject* NxSTATETYPE_OHLCTRADE					;
	PyObject* NxSTATETYPE_EXGQUOTES					;
	PyObject* NxSTATETYPE_MMQUOTES					;
	PyObject* NxLTF_SEARCH_LOCAL					;
	PyObject* NxLTF_SEARCH_NETWORK					;
	PyObject* NxLTF_SEARCH_REMOVEABLE				;
	PyObject* NxST_PERMID							;
	PyObject* NxST_EXCHANGE							;
	PyObject* NxST_TRADECONDITION					;
	PyObject* NxST_QUOTECONDITION					;
	PyObject* NxST_CATEGORY							;
	PyObject* NxST_HALTSTATUS						;
	PyObject* NxST_HALTREASONTYPE					;
	PyObject* NxST_OPENINDICATIONTYPE				;
	PyObject* NxST_ORDERIMBALANCETYPE				;
	PyObject* NxST_TRADEREPORTREASON				;
	PyObject* NxST_EXGCORRECTIONMAP					;
	PyObject* NxST_SYMBOLCHANGETYPE					;
	PyObject* NxST_OHLCFLAGS						;
	PyObject* NxST_EXDIVIDENDATTRIB					;
	PyObject* NxST_OPRAEXCHANGELIST					;
	PyObject* NxST_NASDBIDTICK						;
	PyObject* NxST_MARKETMAKERTYPE					;
	PyObject* NxST_MMQUOTETYPE						;
	PyObject* NxST_REFRESHTYPE						;
	PyObject* NxST_EXPIRATIONCYCLE					;
	PyObject* NxST_VOLUMETYPE						;
	PyObject* NxST_QTEMATCHTYPE						;
	PyObject* NxST_QTEMATCHFLAGS					;
	PyObject* NxST_SIGHIGHLOWTYPE					;
	PyObject* NxST_BBOCHANGEFLAGS					;
	PyObject* NxST_TRADECONDFLAGS					;
	PyObject* NxST_PRICEFLAGS						;
	PyObject* NxST_SETTLEFLAGMAP					;
	PyObject* NxST_SYMBOLFNCLSTATUSMAP				;
	PyObject* NxST_EQUITYCLASSIFICATIONS			;
	PyObject* NxST_SYMBOLTYPES						;
	PyObject* NxCF_EXCLUDE_QUOTES					;
	PyObject* NxCF_EXCLUDE_QUOTES2					;
	PyObject* NxCF_EXCLUDE_OPRA						;
	PyObject* NxCF_FAVOR_NBBO						;
	PyObject* NxCF_MEMORY_ADDRESS					;
	PyObject* NxCF_EXCLUDE_CRC_CHECK				;
	PyObject* NxSAVESTATE_GRADUALLY					;
	PyObject* NxSAVESTATE_ONEPASS					;
	PyObject* NxSAVESTATE_CANCEL					;
	PyObject* NxCALLBACKRETURN_CONTINUE				;
	PyObject* NxCALLBACKRETURN_STOP					;
	PyObject* NxCALLBACKRETURN_RESTART				;
	PyObject* NxAPIERR_NO_ERROR						;
	PyObject* NxAPIERR_USER_STOPPED					;
	PyObject* NxAPIERR_NOT_CALLBACK_THREAD			;
	PyObject* NxAPIERR_BAD_PARAMETERS				;
	PyObject* NxAPIERR_EXCEPTION					;
	PyObject* NxAPIERR_OPEN_TAPE_FILE_FAILED		;
	PyObject* NxAPIERR_INITIALIZE_MEMORY_FAILED		;
	PyObject* NxAPIERR_NOLISTED_EXG					;
	PyObject* NxAPIERR_NOSYMBOLS_FOR_LSTEXG			;
	PyObject* NxAPIERR_NOSESSION_FOR_SYMBOL			;
	PyObject* NxAPIERR_NODATATYPE_FOR_SESSION		;
	PyObject* NxAPIERR_NODATA_FOR_REPEXG			;
	PyObject* NxAPIERR_ZEROED_DATA_FOR_SESSION		;
	PyObject* NxAPIERR_SAVE_STATE_IN_PROGRESS		;
	PyObject* NxAPIERR_NOT_SUPPORTED				;
	PyObject* NxAPIERR_INITALLOC_ERROR				;
	PyObject* NxAPIERR_NSODALLOC_ERROR				;
	PyObject* NxAPIERR_UNSUPPORTED_API				;
	PyObject* LULD_BND_EVT_NONE						;
	PyObject* LULD_BND_EVT_OPENING					;
	PyObject* LULD_BND_EVT_INTRADAY					;
	PyObject* LULD_BND_EVT_RESTATED					;
	PyObject* LULD_BND_EVT_SUSPENDED				;
	PyObject* LULD_BND_EVT_REOPENING				;
	PyObject* LULD_BND_EVT_OUTSIDE_HRS				;
} DefinesObject;

static void Defines_dealloc(DefinesObject* self)
{
	Py_TYPE(self)->tp_free((PyObject*)self);
}

static PyObject* Defines_new(PyTypeObject* type, PyObject* args, PyObject* kwds)//, PyObject *args, PyObject *kwds
{
	DefinesObject* self;
	self = (DefinesObject*)type->tp_alloc(type, 0);
	if (self != NULL) {
		self->NxDATE_DST_UNKNOWN					= PyLong_FromLong(0);
		self->NxDATE_DST_ON							= PyLong_FromLong(1);
		self->NxDATE_DST_OFF						= PyLong_FromLong(2);
		self->NxDATE_DST_ONTODAY					= PyLong_FromLong(3);
		self->NxDATE_DST_OFFTODAY					= PyLong_FromLong(4);
		self->NxDOW_SUNDAY							= PyLong_FromLong(0);
		self->NxDOW_MONDAY							= PyLong_FromLong(1);
		self->NxDOW_TUESDAY							= PyLong_FromLong(2);
		self->NxDOW_WEDNESDAY						= PyLong_FromLong(3);
		self->NxDOW_THURSDAY						= PyLong_FromLong(4);
		self->NxDOW_FRIDAY							= PyLong_FromLong(5);
		self->NxDOW_SATURDAY						= PyLong_FromLong(6);
		self->NxCLOCK_NOCHANGE						= PyLong_FromLong(0);
		self->NxCLOCK_CLOCK							= PyLong_FromLong(1);
		self->NxCLOCK_SECOND						= PyLong_FromLong(2);
		self->NxCLOCK_MINUTE						= PyLong_FromLong(3);
		self->NxCLOCK_HOUR							= PyLong_FromLong(4);
		self->NxCORESTATUS_RUNNING					= PyLong_FromLong(0);
		self->NxCORESTATUS_INITIALIZING				= PyLong_FromLong(1);
		self->NxCORESTATUS_COMPLETE					= PyLong_FromLong(2);
		self->NxCORESTATUS_SYNCHRONIZING			= PyLong_FromLong(3);
		self->NxCORESTATUS_ERROR					= PyLong_FromLong(4);
		self->NxCORESTATUS_WAITFORCOREACCESS		= PyLong_FromLong(5);
		self->NxCORESTATUS_RESTARTING_TAPE			= PyLong_FromLong(6);
		self->NxCORESTATUS_LOADED_STATE				= PyLong_FromLong(7);
		self->NxCORESTATUS_SAVING_STATE				= PyLong_FromLong(8);
		self->NxCORESTATUS_SYMBOLSPIN				= PyLong_FromLong(9);
		self->NxCORESTATUS_TAPEOPEN					= PyLong_FromLong(10);
		self->NxCSRUNMODE_SRC_DISK_FILE				= PyLong_FromLong(0);
		self->NxCSRUNMODE_SRC_ACCESS_FILE			= PyLong_FromLong(1);
		self->NxCSRUNMODE_SRC_ACCESS_MEMORY			= PyLong_FromLong(2);
		self->NxCSRUNMODE_SRC_ACCESS_MB_OLDEST		= PyLong_FromLong(2);
		self->NxCSRUNMODE_SRC_ACCESS_MB_LOWER		= PyLong_FromLong(3);
		self->NxCSRUNMODE_SRC_ACCESS_MB_UPPER		= PyLong_FromLong(4);
		self->NxCSRUNMODE_SRC_ACCESS_MB_SECOND		= PyLong_FromLong(5);
		self->NxCSRUNMODE_SRC_ACCESS_MB_CURRENT		= PyLong_FromLong(6);
		self->NxCSSAVESTATE_CAPTURE					= PyLong_FromLong(0);
		self->NxCSSAVESTATE_COMPLETE				= PyLong_FromLong(1);
		self->NxCSSAVESTATE_ERR_CREATEFILE			= PyLong_FromLong(-1);
		self->NxCSSAVESTATE_ERR_DISKSPACE			= PyLong_FromLong(-2);
		self->NxCSSAVESTATE_ERR_MEMORY				= PyLong_FromLong(-3);
		self->NxCSSYMBOLSPIN_STARTING				= PyLong_FromLong(0);
		self->NxCSSYMBOLSPIN_COMPLETE				= PyLong_FromLong(1);
		self->NxPERMID_REMOVE						= PyLong_FromLong(0x00100000);
		self->NxQTE_NASDBIDTICK_NA					= PyLong_FromLong(0);
		self->NxQTE_NASDBIDTICK_UP					= PyLong_FromLong(1);
		self->NxQTE_NASDBIDTICK_DN					= PyLong_FromLong(2);
		self->NxQTE_NASDBIDTICK_NO					= PyLong_FromLong(3);
		self->NxQTE_REFRESH_REALTIME				= PyLong_FromLong(0);
		self->NxQTE_REFRESH_SOURCE					= PyLong_FromLong(1);
		self->NxQTE_REFRESH_MISMATCH				= PyLong_FromLong(2);
		self->NxQTE_REFRESH_SYNCHRONIZE				= PyLong_FromLong(3);
		self->NxBBOCHANGE_BIDEXG					= PyLong_FromLong(0x01);
		self->NxBBOCHANGE_BIDPRICE					= PyLong_FromLong(0x02);
		self->NxBBOCHANGE_BIDSIZE					= PyLong_FromLong(0x04);
		self->NxBBOCHANGE_ASKEXG					= PyLong_FromLong(0x10);
		self->NxBBOCHANGE_ASKPRICE					= PyLong_FromLong(0x20);
		self->NxBBOCHANGE_ASKSIZE					= PyLong_FromLong(0x40);
		self->NxMMT_UNKNOWN							= PyLong_FromLong(0);
		self->NxMMT_REGULAR							= PyLong_FromLong(1);
		self->NxMMT_PRIMARY							= PyLong_FromLong(2);
		self->NxMMT_PASSIVE							= PyLong_FromLong(3);
		self->NxMMQT_UNKNOWN						= PyLong_FromLong(0);
		self->NxMMQT_REGULAR						= PyLong_FromLong(1);
		self->NxMMQT_PASSIVE						= PyLong_FromLong(2);
		self->NxMMQT_SYNDICATE						= PyLong_FromLong(3);
		self->NxMMQT_PRESYNDICATE					= PyLong_FromLong(4);
		self->NxMMQT_PENALTY						= PyLong_FromLong(5);
		self->NxTPF_SETLAST							= PyLong_FromLong(0x01);
		self->NxTPF_SETHIGH							= PyLong_FromLong(0x02);
		self->NxTPF_SETLOW							= PyLong_FromLong(0x04);
		self->NxTPF_SETOPEN							= PyLong_FromLong(0x08);
		self->NxTPF_EXGINSERT						= PyLong_FromLong(0x10);
		self->NxTPF_EXGCANCEL						= PyLong_FromLong(0x20);
		self->NxTPF_SETTLEMENT						= PyLong_FromLong(0x40);
		self->NxTCF_NOLAST							= PyLong_FromLong(0x01);
		self->NxTCF_NOHIGH							= PyLong_FromLong(0x02);
		self->NxTCF_NOLOW							= PyLong_FromLong(0x04);
		self->NxTVT_INCRVOL							= PyLong_FromLong(0);
		self->NxTVT_NONINCRVOL						= PyLong_FromLong(1);
		self->NxTVT_TOTALVOL						= PyLong_FromLong(2);
		self->NxTVT_TOTALVOLx100					= PyLong_FromLong(3);
		self->NxRTA_SIGHL_EQ						= PyLong_FromLong(0);
		self->NxRTA_SIGHL_LOWEST					= PyLong_FromLong(1);
		self->NxRTA_SIGHL_LOW						= PyLong_FromLong(2);
		self->NxRTA_SIGHL_HIGH						= PyLong_FromLong(3);
		self->NxRTA_SIGHL_HIGHEST					= PyLong_FromLong(4);
		self->NxRTA_QMTYPE_NONE						= PyLong_FromLong(0);
		self->NxRTA_QMTYPE_BID						= PyLong_FromLong(1);
		self->NxRTA_QMTYPE_ASK						= PyLong_FromLong(2);
		self->NxRTA_QMTYPE_INSIDE					= PyLong_FromLong(3);
		self->NxRTA_QMTYPE_BELOWBID					= PyLong_FromLong(4);
		self->NxRTA_QMTYPE_ABOVEASK					= PyLong_FromLong(5);
		self->NxRTA_QTEMATCHFLAG_OLDER				= PyLong_FromLong(0x01);
		self->NxRTA_QTEMATCHFLAG_CROSSED			= PyLong_FromLong(0x02);
		self->NxCFT_UNKNOWN							= PyLong_FromLong(0);
		self->NxCFT_64BIT							= PyLong_FromLong(1);
		self->NxCFT_32BIT							= PyLong_FromLong(2);
		self->NxCFT_STRINGZ							= PyLong_FromLong(3);
		self->NxCFT_DOUBLE							= PyLong_FromLong(4);
		self->NxCFT_PRICE							= PyLong_FromLong(5);
		self->NxCFT_DATE							= PyLong_FromLong(6);
		self->NxCFT_TIME							= PyLong_FromLong(7);
		self->NxCFT_NxSTRING						= PyLong_FromLong(8);
		self->NxCFT_STRING_IDX						= PyLong_FromLong(9);
		self->NxCFT_STRING_MAP						= PyLong_FromLong(10);
		self->NxSS_ADD								= PyLong_FromLong(0);
		self->NxSS_DEL								= PyLong_FromLong(1);
		self->NxSS_MOD								= PyLong_FromLong(2);
		self->NxSPIN_ALL_EXGS						= PyLong_FromLong((unsigned short)-1);
		self->NxSPIN_NON_OPTIONS					= PyLong_FromLong(0);
		self->NxSPIN_OPTIONS						= PyLong_FromLong(0x00000001);
		self->NxMSG_STATUS							= PyLong_FromLong(0);
		self->NxMSG_EXGQUOTE						= PyLong_FromLong(1);
		self->NxMSG_MMQUOTE							= PyLong_FromLong(2);
		self->NxMSG_TRADE							= PyLong_FromLong(3);
		self->NxMSG_CATEGORY						= PyLong_FromLong(4);
		self->NxMSG_SYMBOLCHANGE					= PyLong_FromLong(5);
		self->NxMSG_SYMBOLSPIN						= PyLong_FromLong(6);
		self->NxSTATETYPE_OHLCTRADE					= PyLong_FromLong(1);
		self->NxSTATETYPE_EXGQUOTES					= PyLong_FromLong(2);
		self->NxSTATETYPE_MMQUOTES					= PyLong_FromLong(3);
		self->NxLTF_SEARCH_LOCAL					= PyLong_FromLong(0);
		self->NxLTF_SEARCH_NETWORK					= PyLong_FromLong(0x00000001);
		self->NxLTF_SEARCH_REMOVEABLE				= PyLong_FromLong(0x00000002);
		self->NxST_PERMID							= PyLong_FromLong(2);
		self->NxST_EXCHANGE							= PyLong_FromLong(3);
		self->NxST_TRADECONDITION					= PyLong_FromLong(4);
		self->NxST_QUOTECONDITION					= PyLong_FromLong(5);
		self->NxST_CATEGORY							= PyLong_FromLong(6);
		self->NxST_HALTSTATUS						= PyLong_FromLong(7);
		self->NxST_HALTREASONTYPE					= PyLong_FromLong(8);
		self->NxST_OPENINDICATIONTYPE				= PyLong_FromLong(9);
		self->NxST_ORDERIMBALANCETYPE				= PyLong_FromLong(10);
		self->NxST_TRADEREPORTREASON				= PyLong_FromLong(11);
		self->NxST_EXGCORRECTIONMAP					= PyLong_FromLong(12);
		self->NxST_SYMBOLCHANGETYPE					= PyLong_FromLong(13);
		self->NxST_OHLCFLAGS						= PyLong_FromLong(14);
		self->NxST_EXDIVIDENDATTRIB					= PyLong_FromLong(15);
		self->NxST_OPRAEXCHANGELIST					= PyLong_FromLong(16);
		self->NxST_NASDBIDTICK						= PyLong_FromLong(17);
		self->NxST_MARKETMAKERTYPE					= PyLong_FromLong(18);
		self->NxST_MMQUOTETYPE						= PyLong_FromLong(19);
		self->NxST_REFRESHTYPE						= PyLong_FromLong(20);
		self->NxST_EXPIRATIONCYCLE					= PyLong_FromLong(21);
		self->NxST_VOLUMETYPE						= PyLong_FromLong(22);
		self->NxST_QTEMATCHTYPE						= PyLong_FromLong(23);
		self->NxST_QTEMATCHFLAGS					= PyLong_FromLong(24);
		self->NxST_SIGHIGHLOWTYPE					= PyLong_FromLong(25);
		self->NxST_BBOCHANGEFLAGS					= PyLong_FromLong(26);
		self->NxST_TRADECONDFLAGS					= PyLong_FromLong(27);
		self->NxST_PRICEFLAGS						= PyLong_FromLong(28);
		self->NxST_SETTLEFLAGMAP					= PyLong_FromLong(29);
		self->NxST_SYMBOLFNCLSTATUSMAP				= PyLong_FromLong(30);
		self->NxST_EQUITYCLASSIFICATIONS			= PyLong_FromLong(31);
		self->NxST_SYMBOLTYPES						= PyLong_FromLong(32);
		self->NxCF_EXCLUDE_QUOTES					= PyLong_FromLong(0x00000001);
		self->NxCF_EXCLUDE_QUOTES2					= PyLong_FromLong(0x00000002);
		self->NxCF_EXCLUDE_OPRA						= PyLong_FromLong(0x00000004);
		self->NxCF_FAVOR_NBBO						= PyLong_FromLong(0x00000008);
		self->NxCF_MEMORY_ADDRESS					= PyLong_FromLong(0x04000000);
		self->NxCF_EXCLUDE_CRC_CHECK				= PyLong_FromLong(0x08000000);
		self->NxSAVESTATE_GRADUALLY					= PyLong_FromLong(0);
		self->NxSAVESTATE_ONEPASS					= PyLong_FromLong(0x00000001);
		self->NxSAVESTATE_CANCEL					= PyLong_FromLong(0x00000002);
		self->NxCALLBACKRETURN_CONTINUE				= PyLong_FromLong(0);
		self->NxCALLBACKRETURN_STOP					= PyLong_FromLong(1);
		self->NxCALLBACKRETURN_RESTART				= PyLong_FromLong(2);
		self->NxAPIERR_NO_ERROR						= PyLong_FromLong(0);
		self->NxAPIERR_USER_STOPPED					= PyLong_FromLong(1);
		self->NxAPIERR_NOT_CALLBACK_THREAD			= PyLong_FromLong(-1);
		self->NxAPIERR_BAD_PARAMETERS				= PyLong_FromLong(-2);
		self->NxAPIERR_EXCEPTION					= PyLong_FromLong(-3);
		self->NxAPIERR_OPEN_TAPE_FILE_FAILED		= PyLong_FromLong(-4);
		self->NxAPIERR_INITIALIZE_MEMORY_FAILED		= PyLong_FromLong(-5);
		self->NxAPIERR_NOLISTED_EXG					= PyLong_FromLong(-6);
		self->NxAPIERR_NOSYMBOLS_FOR_LSTEXG			= PyLong_FromLong(-7);
		self->NxAPIERR_NOSESSION_FOR_SYMBOL			= PyLong_FromLong(-8);
		self->NxAPIERR_NODATATYPE_FOR_SESSION		= PyLong_FromLong(-9);
		self->NxAPIERR_NODATA_FOR_REPEXG			= PyLong_FromLong(-10);
		self->NxAPIERR_ZEROED_DATA_FOR_SESSION		= PyLong_FromLong(-11);
		self->NxAPIERR_SAVE_STATE_IN_PROGRESS		= PyLong_FromLong(-12);
		self->NxAPIERR_NOT_SUPPORTED				= PyLong_FromLong(-13);
		self->NxAPIERR_INITALLOC_ERROR				= PyLong_FromLong(-14);
		self->NxAPIERR_NSODALLOC_ERROR				= PyLong_FromLong(-15);
		self->NxAPIERR_UNSUPPORTED_API				= PyLong_FromLong(-16);
		self->LULD_BND_EVT_NONE						= PyLong_FromLong(0x00);
		self->LULD_BND_EVT_OPENING					= PyLong_FromLong(0x01);
		self->LULD_BND_EVT_INTRADAY					= PyLong_FromLong(0x02);
		self->LULD_BND_EVT_RESTATED					= PyLong_FromLong(0x03);
		self->LULD_BND_EVT_SUSPENDED				= PyLong_FromLong(0x04);
		self->LULD_BND_EVT_REOPENING				= PyLong_FromLong(0x05);
		self->LULD_BND_EVT_OUTSIDE_HRS				= PyLong_FromLong(0x06);
	}
	return (PyObject*)self;
}

static PyMemberDef Defines_members[] = {
	{"NxDATE_DST_UNKNOWN",T_OBJECT_EX, offsetof(DefinesObject,NxDATE_DST_UNKNOWN),1,"NxDATE_DST_UNKNOWN"},
	{"NxDATE_DST_ON",T_OBJECT_EX, offsetof(DefinesObject,NxDATE_DST_ON),1,"NxDATE_DST_ON"},
	{"NxDATE_DST_OFF",T_OBJECT_EX, offsetof(DefinesObject,NxDATE_DST_OFF),1,"NxDATE_DST_OFF"},
	{"NxDATE_DST_ONTODAY",T_OBJECT_EX, offsetof(DefinesObject,NxDATE_DST_ONTODAY),1,"NxDATE_DST_ONTODAY"},
	{"NxDATE_DST_OFFTODAY",T_OBJECT_EX, offsetof(DefinesObject,NxDATE_DST_OFFTODAY),1,"NxDATE_DST_OFFTODAY"},
	{"NxDOW_SUNDAY",T_OBJECT_EX, offsetof(DefinesObject,NxDOW_SUNDAY),1,"NxDOW_SUNDAY"},
	{"NxDOW_MONDAY",T_OBJECT_EX, offsetof(DefinesObject,NxDOW_MONDAY),1,"NxDOW_MONDAY"},
	{"NxDOW_TUESDAY",T_OBJECT_EX, offsetof(DefinesObject,NxDOW_TUESDAY),1,"NxDOW_TUESDAY"},
	{"NxDOW_WEDNESDAY",T_OBJECT_EX, offsetof(DefinesObject,NxDOW_WEDNESDAY),1,"NxDOW_WEDNESDAY"},
	{"NxDOW_THURSDAY",T_OBJECT_EX, offsetof(DefinesObject,NxDOW_THURSDAY),1,"NxDOW_THURSDAY"},
	{"NxDOW_FRIDAY",T_OBJECT_EX, offsetof(DefinesObject,NxDOW_FRIDAY),1,"NxDOW_FRIDAY"},
	{"NxDOW_SATURDAY",T_OBJECT_EX, offsetof(DefinesObject,NxDOW_SATURDAY),1,"NxDOW_SATURDAY"},
	{"NxCLOCK_NOCHANGE",T_OBJECT_EX, offsetof(DefinesObject,NxCLOCK_NOCHANGE),1,"NxCLOCK_NOCHANGE"},
	{"NxCLOCK_CLOCK",T_OBJECT_EX, offsetof(DefinesObject,NxCLOCK_CLOCK),1,"NxCLOCK_CLOCK"},
	{"NxCLOCK_SECOND",T_OBJECT_EX, offsetof(DefinesObject,NxCLOCK_SECOND),1,"NxCLOCK_SECOND"},
	{"NxCLOCK_MINUTE",T_OBJECT_EX, offsetof(DefinesObject,NxCLOCK_MINUTE),1,"NxCLOCK_MINUTE"},
	{"NxCLOCK_HOUR",T_OBJECT_EX, offsetof(DefinesObject,NxCLOCK_HOUR),1,"NxCLOCK_HOUR"},
	{"NxCORESTATUS_RUNNING",T_OBJECT_EX, offsetof(DefinesObject,NxCORESTATUS_RUNNING),1,"NxCORESTATUS_RUNNING"},
	{"NxCORESTATUS_INITIALIZING",T_OBJECT_EX, offsetof(DefinesObject,NxCORESTATUS_INITIALIZING),1,"NxCORESTATUS_INITIALIZING"},
	{"NxCORESTATUS_COMPLETE",T_OBJECT_EX, offsetof(DefinesObject,NxCORESTATUS_COMPLETE),1,"NxCORESTATUS_COMPLETE"},
	{"NxCORESTATUS_SYNCHRONIZING",T_OBJECT_EX, offsetof(DefinesObject,NxCORESTATUS_SYNCHRONIZING),1,"NxCORESTATUS_SYNCHRONIZING"},
	{"NxCORESTATUS_ERROR",T_OBJECT_EX, offsetof(DefinesObject,NxCORESTATUS_ERROR),1,"NxCORESTATUS_ERROR"},
	{"NxCORESTATUS_WAITFORCOREACCESS",T_OBJECT_EX, offsetof(DefinesObject,NxCORESTATUS_WAITFORCOREACCESS),1,"NxCORESTATUS_WAITFORCOREACCESS"},
	{"NxCORESTATUS_RESTARTING_TAPE",T_OBJECT_EX, offsetof(DefinesObject,NxCORESTATUS_RESTARTING_TAPE),1,"NxCORESTATUS_RESTARTING_TAPE"},
	{"NxCORESTATUS_LOADED_STATE",T_OBJECT_EX, offsetof(DefinesObject,NxCORESTATUS_LOADED_STATE),1,"NxCORESTATUS_LOADED_STATE"},
	{"NxCORESTATUS_SAVING_STATE",T_OBJECT_EX, offsetof(DefinesObject,NxCORESTATUS_SAVING_STATE),1,"NxCORESTATUS_SAVING_STATE"},
	{"NxCORESTATUS_SYMBOLSPIN",T_OBJECT_EX, offsetof(DefinesObject,NxCORESTATUS_SYMBOLSPIN),1,"NxCORESTATUS_SYMBOLSPIN"},
	{"NxCORESTATUS_TAPEOPEN",T_OBJECT_EX, offsetof(DefinesObject,NxCORESTATUS_TAPEOPEN),1,"NxCORESTATUS_TAPEOPEN"},
	{"NxCSRUNMODE_SRC_DISK_FILE",T_OBJECT_EX, offsetof(DefinesObject,NxCSRUNMODE_SRC_DISK_FILE),1,"NxCSRUNMODE_SRC_DISK_FILE"},
	{"NxCSRUNMODE_SRC_ACCESS_FILE",T_OBJECT_EX, offsetof(DefinesObject,NxCSRUNMODE_SRC_ACCESS_FILE),1,"NxCSRUNMODE_SRC_ACCESS_FILE"},
	{"NxCSRUNMODE_SRC_ACCESS_MEMORY",T_OBJECT_EX, offsetof(DefinesObject,NxCSRUNMODE_SRC_ACCESS_MEMORY),1,"NxCSRUNMODE_SRC_ACCESS_MEMORY"},
	{"NxCSRUNMODE_SRC_ACCESS_MB_OLDEST",T_OBJECT_EX, offsetof(DefinesObject,NxCSRUNMODE_SRC_ACCESS_MB_OLDEST),1,"NxCSRUNMODE_SRC_ACCESS_MB_OLDEST"},
	{"NxCSRUNMODE_SRC_ACCESS_MB_LOWER",T_OBJECT_EX, offsetof(DefinesObject,NxCSRUNMODE_SRC_ACCESS_MB_LOWER),1,"NxCSRUNMODE_SRC_ACCESS_MB_LOWER"},
	{"NxCSRUNMODE_SRC_ACCESS_MB_UPPER",T_OBJECT_EX, offsetof(DefinesObject,NxCSRUNMODE_SRC_ACCESS_MB_UPPER),1,"NxCSRUNMODE_SRC_ACCESS_MB_UPPER"},
	{"NxCSRUNMODE_SRC_ACCESS_MB_SECOND",T_OBJECT_EX, offsetof(DefinesObject,NxCSRUNMODE_SRC_ACCESS_MB_SECOND),1,"NxCSRUNMODE_SRC_ACCESS_MB_SECOND"},
	{"NxCSRUNMODE_SRC_ACCESS_MB_CURRENT",T_OBJECT_EX, offsetof(DefinesObject,NxCSRUNMODE_SRC_ACCESS_MB_CURRENT),1,"NxCSRUNMODE_SRC_ACCESS_MB_CURRENT"},
	{"NxCSSAVESTATE_CAPTURE",T_OBJECT_EX, offsetof(DefinesObject,NxCSSAVESTATE_CAPTURE),1,"NxCSSAVESTATE_CAPTURE"},
	{"NxCSSAVESTATE_COMPLETE",T_OBJECT_EX, offsetof(DefinesObject,NxCSSAVESTATE_COMPLETE),1,"NxCSSAVESTATE_COMPLETE"},
	{"NxCSSAVESTATE_ERR_CREATEFILE",T_OBJECT_EX, offsetof(DefinesObject,NxCSSAVESTATE_ERR_CREATEFILE),1,"NxCSSAVESTATE_ERR_CREATEFILE"},
	{"NxCSSAVESTATE_ERR_DISKSPACE",T_OBJECT_EX, offsetof(DefinesObject,NxCSSAVESTATE_ERR_DISKSPACE),1,"NxCSSAVESTATE_ERR_DISKSPACE"},
	{"NxCSSAVESTATE_ERR_MEMORY",T_OBJECT_EX, offsetof(DefinesObject,NxCSSAVESTATE_ERR_MEMORY),1,"NxCSSAVESTATE_ERR_MEMORY"},
	{"NxCSSYMBOLSPIN_STARTING",T_OBJECT_EX, offsetof(DefinesObject,NxCSSYMBOLSPIN_STARTING),1,"NxCSSYMBOLSPIN_STARTING"},
	{"NxCSSYMBOLSPIN_COMPLETE",T_OBJECT_EX, offsetof(DefinesObject,NxCSSYMBOLSPIN_COMPLETE),1,"NxCSSYMBOLSPIN_COMPLETE"},
	{"NxPERMID_REMOVE",T_OBJECT_EX, offsetof(DefinesObject,NxPERMID_REMOVE),1,"NxPERMID_REMOVE"},
	{"NxQTE_NASDBIDTICK_NA",T_OBJECT_EX, offsetof(DefinesObject,NxQTE_NASDBIDTICK_NA),1,"NxQTE_NASDBIDTICK_NA"},
	{"NxQTE_NASDBIDTICK_UP",T_OBJECT_EX, offsetof(DefinesObject,NxQTE_NASDBIDTICK_UP),1,"NxQTE_NASDBIDTICK_UP"},
	{"NxQTE_NASDBIDTICK_DN",T_OBJECT_EX, offsetof(DefinesObject,NxQTE_NASDBIDTICK_DN),1,"NxQTE_NASDBIDTICK_DN"},
	{"NxQTE_NASDBIDTICK_NO",T_OBJECT_EX, offsetof(DefinesObject,NxQTE_NASDBIDTICK_NO),1,"NxQTE_NASDBIDTICK_NO"},
	{"NxQTE_REFRESH_REALTIME",T_OBJECT_EX, offsetof(DefinesObject,NxQTE_REFRESH_REALTIME),1,"NxQTE_REFRESH_REALTIME"},
	{"NxQTE_REFRESH_SOURCE",T_OBJECT_EX, offsetof(DefinesObject,NxQTE_REFRESH_SOURCE),1,"NxQTE_REFRESH_SOURCE"},
	{"NxQTE_REFRESH_MISMATCH",T_OBJECT_EX, offsetof(DefinesObject,NxQTE_REFRESH_MISMATCH),1,"NxQTE_REFRESH_MISMATCH"},
	{"NxQTE_REFRESH_SYNCHRONIZE",T_OBJECT_EX, offsetof(DefinesObject,NxQTE_REFRESH_SYNCHRONIZE),1,"NxQTE_REFRESH_SYNCHRONIZE"},
	{"NxBBOCHANGE_BIDEXG",T_OBJECT_EX, offsetof(DefinesObject,NxBBOCHANGE_BIDEXG),1,"NxBBOCHANGE_BIDEXG"},
	{"NxBBOCHANGE_BIDPRICE",T_OBJECT_EX, offsetof(DefinesObject,NxBBOCHANGE_BIDPRICE),1,"NxBBOCHANGE_BIDPRICE"},
	{"NxBBOCHANGE_BIDSIZE",T_OBJECT_EX, offsetof(DefinesObject,NxBBOCHANGE_BIDSIZE),1,"NxBBOCHANGE_BIDSIZE"},
	{"NxBBOCHANGE_ASKEXG",T_OBJECT_EX, offsetof(DefinesObject,NxBBOCHANGE_ASKEXG),1,"NxBBOCHANGE_ASKEXG"},
	{"NxBBOCHANGE_ASKPRICE",T_OBJECT_EX, offsetof(DefinesObject,NxBBOCHANGE_ASKPRICE),1,"NxBBOCHANGE_ASKPRICE"},
	{"NxBBOCHANGE_ASKSIZE",T_OBJECT_EX, offsetof(DefinesObject,NxBBOCHANGE_ASKSIZE),1,"NxBBOCHANGE_ASKSIZE"},
	{"NxMMT_UNKNOWN",T_OBJECT_EX, offsetof(DefinesObject,NxMMT_UNKNOWN),1,"NxMMT_UNKNOWN"},
	{"NxMMT_REGULAR",T_OBJECT_EX, offsetof(DefinesObject,NxMMT_REGULAR),1,"NxMMT_REGULAR"},
	{"NxMMT_PRIMARY",T_OBJECT_EX, offsetof(DefinesObject,NxMMT_PRIMARY),1,"NxMMT_PRIMARY"},
	{"NxMMT_PASSIVE",T_OBJECT_EX, offsetof(DefinesObject,NxMMT_PASSIVE),1,"NxMMT_PASSIVE"},
	{"NxMMQT_UNKNOWN",T_OBJECT_EX, offsetof(DefinesObject,NxMMQT_UNKNOWN),1,"NxMMQT_UNKNOWN"},
	{"NxMMQT_REGULAR",T_OBJECT_EX, offsetof(DefinesObject,NxMMQT_REGULAR),1,"NxMMQT_REGULAR"},
	{"NxMMQT_PASSIVE",T_OBJECT_EX, offsetof(DefinesObject,NxMMQT_PASSIVE),1,"NxMMQT_PASSIVE"},
	{"NxMMQT_SYNDICATE",T_OBJECT_EX, offsetof(DefinesObject,NxMMQT_SYNDICATE),1,"NxMMQT_SYNDICATE"},
	{"NxMMQT_PRESYNDICATE",T_OBJECT_EX, offsetof(DefinesObject,NxMMQT_PRESYNDICATE),1,"NxMMQT_PRESYNDICATE"},
	{"NxMMQT_PENALTY",T_OBJECT_EX, offsetof(DefinesObject,NxMMQT_PENALTY),1,"NxMMQT_PENALTY"},
	{"NxTPF_SETLAST",T_OBJECT_EX, offsetof(DefinesObject,NxTPF_SETLAST),1,"NxTPF_SETLAST"},
	{"NxTPF_SETHIGH",T_OBJECT_EX, offsetof(DefinesObject,NxTPF_SETHIGH),1,"NxTPF_SETHIGH"},
	{"NxTPF_SETLOW",T_OBJECT_EX, offsetof(DefinesObject,NxTPF_SETLOW),1,"NxTPF_SETLOW"},
	{"NxTPF_SETOPEN",T_OBJECT_EX, offsetof(DefinesObject,NxTPF_SETOPEN),1,"NxTPF_SETOPEN"},
	{"NxTPF_EXGINSERT",T_OBJECT_EX, offsetof(DefinesObject,NxTPF_EXGINSERT),1,"NxTPF_EXGINSERT"},
	{"NxTPF_EXGCANCEL",T_OBJECT_EX, offsetof(DefinesObject,NxTPF_EXGCANCEL),1,"NxTPF_EXGCANCEL"},
	{"NxTPF_SETTLEMENT",T_OBJECT_EX, offsetof(DefinesObject,NxTPF_SETTLEMENT),1,"NxTPF_SETTLEMENT"},
	{"NxTCF_NOLAST",T_OBJECT_EX, offsetof(DefinesObject,NxTCF_NOLAST),1,"NxTCF_NOLAST"},
	{"NxTCF_NOHIGH",T_OBJECT_EX, offsetof(DefinesObject,NxTCF_NOHIGH),1,"NxTCF_NOHIGH"},
	{"NxTCF_NOLOW",T_OBJECT_EX, offsetof(DefinesObject,NxTCF_NOLOW),1,"NxTCF_NOLOW"},
	{"NxTVT_INCRVOL",T_OBJECT_EX, offsetof(DefinesObject,NxTVT_INCRVOL),1,"NxTVT_INCRVOL"},
	{"NxTVT_NONINCRVOL",T_OBJECT_EX, offsetof(DefinesObject,NxTVT_NONINCRVOL),1,"NxTVT_NONINCRVOL"},
	{"NxTVT_TOTALVOL",T_OBJECT_EX, offsetof(DefinesObject,NxTVT_TOTALVOL),1,"NxTVT_TOTALVOL"},
	{"NxTVT_TOTALVOLx100",T_OBJECT_EX, offsetof(DefinesObject,NxTVT_TOTALVOLx100),1,"NxTVT_TOTALVOLx100"},
	{"NxRTA_SIGHL_EQ",T_OBJECT_EX, offsetof(DefinesObject,NxRTA_SIGHL_EQ),1,"NxRTA_SIGHL_EQ"},
	{"NxRTA_SIGHL_LOWEST",T_OBJECT_EX, offsetof(DefinesObject,NxRTA_SIGHL_LOWEST),1,"NxRTA_SIGHL_LOWEST"},
	{"NxRTA_SIGHL_LOW",T_OBJECT_EX, offsetof(DefinesObject,NxRTA_SIGHL_LOW),1,"NxRTA_SIGHL_LOW"},
	{"NxRTA_SIGHL_HIGH",T_OBJECT_EX, offsetof(DefinesObject,NxRTA_SIGHL_HIGH),1,"NxRTA_SIGHL_HIGH"},
	{"NxRTA_SIGHL_HIGHEST",T_OBJECT_EX, offsetof(DefinesObject,NxRTA_SIGHL_HIGHEST),1,"NxRTA_SIGHL_HIGHEST"},
	{"NxRTA_QMTYPE_NONE",T_OBJECT_EX, offsetof(DefinesObject,NxRTA_QMTYPE_NONE),1,"NxRTA_QMTYPE_NONE"},
	{"NxRTA_QMTYPE_BID",T_OBJECT_EX, offsetof(DefinesObject,NxRTA_QMTYPE_BID),1,"NxRTA_QMTYPE_BID"},
	{"NxRTA_QMTYPE_ASK",T_OBJECT_EX, offsetof(DefinesObject,NxRTA_QMTYPE_ASK),1,"NxRTA_QMTYPE_ASK"},
	{"NxRTA_QMTYPE_INSIDE",T_OBJECT_EX, offsetof(DefinesObject,NxRTA_QMTYPE_INSIDE),1,"NxRTA_QMTYPE_INSIDE"},
	{"NxRTA_QMTYPE_BELOWBID",T_OBJECT_EX, offsetof(DefinesObject,NxRTA_QMTYPE_BELOWBID),1,"NxRTA_QMTYPE_BELOWBID"},
	{"NxRTA_QMTYPE_ABOVEASK",T_OBJECT_EX, offsetof(DefinesObject,NxRTA_QMTYPE_ABOVEASK),1,"NxRTA_QMTYPE_ABOVEASK"},
	{"NxRTA_QTEMATCHFLAG_OLDER",T_OBJECT_EX, offsetof(DefinesObject,NxRTA_QTEMATCHFLAG_OLDER),1,"NxRTA_QTEMATCHFLAG_OLDER"},
	{"NxRTA_QTEMATCHFLAG_CROSSED",T_OBJECT_EX, offsetof(DefinesObject,NxRTA_QTEMATCHFLAG_CROSSED),1,"NxRTA_QTEMATCHFLAG_CROSSED"},
	{"NxCFT_UNKNOWN",T_OBJECT_EX, offsetof(DefinesObject,NxCFT_UNKNOWN),1,"NxCFT_UNKNOWN"},
	{"NxCFT_64BIT",T_OBJECT_EX, offsetof(DefinesObject,NxCFT_64BIT),1,"NxCFT_64BIT"},
	{"NxCFT_32BIT",T_OBJECT_EX, offsetof(DefinesObject,NxCFT_32BIT),1,"NxCFT_32BIT"},
	{"NxCFT_STRINGZ",T_OBJECT_EX, offsetof(DefinesObject,NxCFT_STRINGZ),1,"NxCFT_STRINGZ"},
	{"NxCFT_DOUBLE",T_OBJECT_EX, offsetof(DefinesObject,NxCFT_DOUBLE),1,"NxCFT_DOUBLE"},
	{"NxCFT_PRICE",T_OBJECT_EX, offsetof(DefinesObject,NxCFT_PRICE),1,"NxCFT_PRICE"},
	{"NxCFT_DATE",T_OBJECT_EX, offsetof(DefinesObject,NxCFT_DATE),1,"NxCFT_DATE"},
	{"NxCFT_TIME",T_OBJECT_EX, offsetof(DefinesObject,NxCFT_TIME),1,"NxCFT_TIME"},
	{"NxCFT_NxSTRING",T_OBJECT_EX, offsetof(DefinesObject,NxCFT_NxSTRING),1,"NxCFT_NxSTRING"},
	{"NxCFT_STRING_IDX",T_OBJECT_EX, offsetof(DefinesObject,NxCFT_STRING_IDX),1,"NxCFT_STRING_IDX"},
	{"NxCFT_STRING_MAP",T_OBJECT_EX, offsetof(DefinesObject,NxCFT_STRING_MAP),1,"NxCFT_STRING_MAP"},
	{"NxSS_ADD",T_OBJECT_EX, offsetof(DefinesObject,NxSS_ADD),1,"NxSS_ADD"},
	{"NxSS_DEL",T_OBJECT_EX, offsetof(DefinesObject,NxSS_DEL),1,"NxSS_DEL"},
	{"NxSS_MOD",T_OBJECT_EX, offsetof(DefinesObject,NxSS_MOD),1,"NxSS_MOD"},
	{"NxSPIN_ALL_EXGS",T_OBJECT_EX, offsetof(DefinesObject,NxSPIN_ALL_EXGS),1,"NxSPIN_ALL_EXGS"},
	{"NxSPIN_NON_OPTIONS",T_OBJECT_EX, offsetof(DefinesObject,NxSPIN_NON_OPTIONS),1,"NxSPIN_NON_OPTIONS"},
	{"NxSPIN_OPTIONS",T_OBJECT_EX, offsetof(DefinesObject,NxSPIN_OPTIONS),1,"NxSPIN_OPTIONS"},
	{"NxMSG_STATUS",T_OBJECT_EX, offsetof(DefinesObject,NxMSG_STATUS),1,"NxMSG_STATUS"},
	{"NxMSG_EXGQUOTE",T_OBJECT_EX, offsetof(DefinesObject,NxMSG_EXGQUOTE),1,"NxMSG_EXGQUOTE"},
	{"NxMSG_MMQUOTE",T_OBJECT_EX, offsetof(DefinesObject,NxMSG_MMQUOTE),1,"NxMSG_MMQUOTE"},
	{"NxMSG_TRADE",T_OBJECT_EX, offsetof(DefinesObject,NxMSG_TRADE),1,"NxMSG_TRADE"},
	{"NxMSG_CATEGORY",T_OBJECT_EX, offsetof(DefinesObject,NxMSG_CATEGORY),1,"NxMSG_CATEGORY"},
	{"NxMSG_SYMBOLCHANGE",T_OBJECT_EX, offsetof(DefinesObject,NxMSG_SYMBOLCHANGE),1,"NxMSG_SYMBOLCHANGE"},
	{"NxMSG_SYMBOLSPIN",T_OBJECT_EX, offsetof(DefinesObject,NxMSG_SYMBOLSPIN),1,"NxMSG_SYMBOLSPIN"},
	{"NxSTATETYPE_OHLCTRADE",T_OBJECT_EX, offsetof(DefinesObject,NxSTATETYPE_OHLCTRADE),1,"NxSTATETYPE_OHLCTRADE"},
	{"NxSTATETYPE_EXGQUOTES",T_OBJECT_EX, offsetof(DefinesObject,NxSTATETYPE_EXGQUOTES),1,"NxSTATETYPE_EXGQUOTES"},
	{"NxSTATETYPE_MMQUOTES",T_OBJECT_EX, offsetof(DefinesObject,NxSTATETYPE_MMQUOTES),1,"NxSTATETYPE_MMQUOTES"},
	{"NxLTF_SEARCH_LOCAL",T_OBJECT_EX, offsetof(DefinesObject,NxLTF_SEARCH_LOCAL),1,"NxLTF_SEARCH_LOCAL"},
	{"NxLTF_SEARCH_NETWORK",T_OBJECT_EX, offsetof(DefinesObject,NxLTF_SEARCH_NETWORK),1,"NxLTF_SEARCH_NETWORK"},
	{"NxLTF_SEARCH_REMOVEABLE",T_OBJECT_EX, offsetof(DefinesObject,NxLTF_SEARCH_REMOVEABLE),1,"NxLTF_SEARCH_REMOVEABLE"},
	{"NxST_PERMID",T_OBJECT_EX, offsetof(DefinesObject,NxST_PERMID),1,"NxST_PERMID"},
	{"NxST_EXCHANGE",T_OBJECT_EX, offsetof(DefinesObject,NxST_EXCHANGE),1,"NxST_EXCHANGE"},
	{"NxST_TRADECONDITION",T_OBJECT_EX, offsetof(DefinesObject,NxST_TRADECONDITION),1,"NxST_TRADECONDITION"},
	{"NxST_QUOTECONDITION",T_OBJECT_EX, offsetof(DefinesObject,NxST_QUOTECONDITION),1,"NxST_QUOTECONDITION"},
	{"NxST_CATEGORY",T_OBJECT_EX, offsetof(DefinesObject,NxST_CATEGORY),1,"NxST_CATEGORY"},
	{"NxST_HALTSTATUS",T_OBJECT_EX, offsetof(DefinesObject,NxST_HALTSTATUS),1,"NxST_HALTSTATUS"},
	{"NxST_HALTREASONTYPE",T_OBJECT_EX, offsetof(DefinesObject,NxST_HALTREASONTYPE),1,"NxST_HALTREASONTYPE"},
	{"NxST_OPENINDICATIONTYPE",T_OBJECT_EX, offsetof(DefinesObject,NxST_OPENINDICATIONTYPE),1,"NxST_OPENINDICATIONTYPE"},
	{"NxST_ORDERIMBALANCETYPE",T_OBJECT_EX, offsetof(DefinesObject,NxST_ORDERIMBALANCETYPE),1,"NxST_ORDERIMBALANCETYPE"},
	{"NxST_TRADEREPORTREASON",T_OBJECT_EX, offsetof(DefinesObject,NxST_TRADEREPORTREASON),1,"NxST_TRADEREPORTREASON"},
	{"NxST_EXGCORRECTIONMAP",T_OBJECT_EX, offsetof(DefinesObject,NxST_EXGCORRECTIONMAP),1,"NxST_EXGCORRECTIONMAP"},
	{"NxST_SYMBOLCHANGETYPE",T_OBJECT_EX, offsetof(DefinesObject,NxST_SYMBOLCHANGETYPE),1,"NxST_SYMBOLCHANGETYPE"},
	{"NxST_OHLCFLAGS",T_OBJECT_EX, offsetof(DefinesObject,NxST_OHLCFLAGS),1,"NxST_OHLCFLAGS"},
	{"NxST_EXDIVIDENDATTRIB",T_OBJECT_EX, offsetof(DefinesObject,NxST_EXDIVIDENDATTRIB),1,"NxST_EXDIVIDENDATTRIB"},
	{"NxST_OPRAEXCHANGELIST",T_OBJECT_EX, offsetof(DefinesObject,NxST_OPRAEXCHANGELIST),1,"NxST_OPRAEXCHANGELIST"},
	{"NxST_NASDBIDTICK",T_OBJECT_EX, offsetof(DefinesObject,NxST_NASDBIDTICK),1,"NxST_NASDBIDTICK"},
	{"NxST_MARKETMAKERTYPE",T_OBJECT_EX, offsetof(DefinesObject,NxST_MARKETMAKERTYPE),1,"NxST_MARKETMAKERTYPE"},
	{"NxST_MMQUOTETYPE",T_OBJECT_EX, offsetof(DefinesObject,NxST_MMQUOTETYPE),1,"NxST_MMQUOTETYPE"},
	{"NxST_REFRESHTYPE",T_OBJECT_EX, offsetof(DefinesObject,NxST_REFRESHTYPE),1,"NxST_REFRESHTYPE"},
	{"NxST_EXPIRATIONCYCLE",T_OBJECT_EX, offsetof(DefinesObject,NxST_EXPIRATIONCYCLE),1,"NxST_EXPIRATIONCYCLE"},
	{"NxST_VOLUMETYPE",T_OBJECT_EX, offsetof(DefinesObject,NxST_VOLUMETYPE),1,"NxST_VOLUMETYPE"},
	{"NxST_QTEMATCHTYPE",T_OBJECT_EX, offsetof(DefinesObject,NxST_QTEMATCHTYPE),1,"NxST_QTEMATCHTYPE"},
	{"NxST_QTEMATCHFLAGS",T_OBJECT_EX, offsetof(DefinesObject,NxST_QTEMATCHFLAGS),1,"NxST_QTEMATCHFLAGS"},
	{"NxST_SIGHIGHLOWTYPE",T_OBJECT_EX, offsetof(DefinesObject,NxST_SIGHIGHLOWTYPE),1,"NxST_SIGHIGHLOWTYPE"},
	{"NxST_BBOCHANGEFLAGS",T_OBJECT_EX, offsetof(DefinesObject,NxST_BBOCHANGEFLAGS),1,"NxST_BBOCHANGEFLAGS"},
	{"NxST_TRADECONDFLAGS",T_OBJECT_EX, offsetof(DefinesObject,NxST_TRADECONDFLAGS),1,"NxST_TRADECONDFLAGS"},
	{"NxST_PRICEFLAGS",T_OBJECT_EX, offsetof(DefinesObject,NxST_PRICEFLAGS),1,"NxST_PRICEFLAGS"},
	{"NxST_SETTLEFLAGMAP",T_OBJECT_EX, offsetof(DefinesObject,NxST_SETTLEFLAGMAP),1,"NxST_SETTLEFLAGMAP"},
	{"NxST_SYMBOLFNCLSTATUSMAP",T_OBJECT_EX, offsetof(DefinesObject,NxST_SYMBOLFNCLSTATUSMAP),1,"NxST_SYMBOLFNCLSTATUSMAP"},
	{"NxST_EQUITYCLASSIFICATIONS",T_OBJECT_EX, offsetof(DefinesObject,NxST_EQUITYCLASSIFICATIONS),1,"NxST_EQUITYCLASSIFICATIONS"},
	{"NxST_SYMBOLTYPES",T_OBJECT_EX, offsetof(DefinesObject,NxST_SYMBOLTYPES),1,"NxST_SYMBOLTYPES"},
	{"NxCF_EXCLUDE_QUOTES",T_OBJECT_EX, offsetof(DefinesObject,NxCF_EXCLUDE_QUOTES),1,"NxCF_EXCLUDE_QUOTES"},
	{"NxCF_EXCLUDE_QUOTES2",T_OBJECT_EX, offsetof(DefinesObject,NxCF_EXCLUDE_QUOTES2),1,"NxCF_EXCLUDE_QUOTES2"},
	{"NxCF_EXCLUDE_OPRA",T_OBJECT_EX, offsetof(DefinesObject,NxCF_EXCLUDE_OPRA),1,"NxCF_EXCLUDE_OPRA"},
	{"NxCF_FAVOR_NBBO",T_OBJECT_EX, offsetof(DefinesObject,NxCF_FAVOR_NBBO),1,"NxCF_FAVOR_NBBO"},
	{"NxCF_MEMORY_ADDRESS",T_OBJECT_EX, offsetof(DefinesObject,NxCF_MEMORY_ADDRESS),1,"NxCF_MEMORY_ADDRESS"},
	{"NxCF_EXCLUDE_CRC_CHECK",T_OBJECT_EX, offsetof(DefinesObject,NxCF_EXCLUDE_CRC_CHECK),1,"NxCF_EXCLUDE_CRC_CHECK"},
	{"NxSAVESTATE_GRADUALLY",T_OBJECT_EX, offsetof(DefinesObject,NxSAVESTATE_GRADUALLY),1,"NxSAVESTATE_GRADUALLY"},
	{"NxSAVESTATE_ONEPASS",T_OBJECT_EX, offsetof(DefinesObject,NxSAVESTATE_ONEPASS),1,"NxSAVESTATE_ONEPASS"},
	{"NxSAVESTATE_CANCEL",T_OBJECT_EX, offsetof(DefinesObject,NxSAVESTATE_CANCEL),1,"NxSAVESTATE_CANCEL"},
	{"NxCALLBACKRETURN_CONTINUE",T_OBJECT_EX, offsetof(DefinesObject,NxCALLBACKRETURN_CONTINUE),1,"NxCALLBACKRETURN_CONTINUE"},
	{"NxCALLBACKRETURN_STOP",T_OBJECT_EX, offsetof(DefinesObject,NxCALLBACKRETURN_STOP),1,"NxCALLBACKRETURN_STOP"},
	{"NxCALLBACKRETURN_RESTART",T_OBJECT_EX, offsetof(DefinesObject,NxCALLBACKRETURN_RESTART),1,"NxCALLBACKRETURN_RESTART"},
	{"NxAPIERR_NO_ERROR",T_OBJECT_EX, offsetof(DefinesObject,NxAPIERR_NO_ERROR),1,"NxAPIERR_NO_ERROR"},
	{"NxAPIERR_USER_STOPPED",T_OBJECT_EX, offsetof(DefinesObject,NxAPIERR_USER_STOPPED),1,"NxAPIERR_USER_STOPPED"},
	{"NxAPIERR_NOT_CALLBACK_THREAD",T_OBJECT_EX, offsetof(DefinesObject,NxAPIERR_NOT_CALLBACK_THREAD),1,"NxAPIERR_NOT_CALLBACK_THREAD"},
	{"NxAPIERR_BAD_PARAMETERS",T_OBJECT_EX, offsetof(DefinesObject,NxAPIERR_BAD_PARAMETERS),1,"NxAPIERR_BAD_PARAMETERS"},
	{"NxAPIERR_EXCEPTION",T_OBJECT_EX, offsetof(DefinesObject,NxAPIERR_EXCEPTION),1,"NxAPIERR_EXCEPTION"},
	{"NxAPIERR_OPEN_TAPE_FILE_FAILED",T_OBJECT_EX, offsetof(DefinesObject,NxAPIERR_OPEN_TAPE_FILE_FAILED),1,"NxAPIERR_OPEN_TAPE_FILE_FAILED"},
	{"NxAPIERR_INITIALIZE_MEMORY_FAILED",T_OBJECT_EX, offsetof(DefinesObject,NxAPIERR_INITIALIZE_MEMORY_FAILED),1,"NxAPIERR_INITIALIZE_MEMORY_FAILED"},
	{"NxAPIERR_NOLISTED_EXG",T_OBJECT_EX, offsetof(DefinesObject,NxAPIERR_NOLISTED_EXG),1,"NxAPIERR_NOLISTED_EXG"},
	{"NxAPIERR_NOSYMBOLS_FOR_LSTEXG",T_OBJECT_EX, offsetof(DefinesObject,NxAPIERR_NOSYMBOLS_FOR_LSTEXG),1,"NxAPIERR_NOSYMBOLS_FOR_LSTEXG"},
	{"NxAPIERR_NOSESSION_FOR_SYMBOL",T_OBJECT_EX, offsetof(DefinesObject,NxAPIERR_NOSESSION_FOR_SYMBOL),1,"NxAPIERR_NOSESSION_FOR_SYMBOL"},
	{"NxAPIERR_NODATATYPE_FOR_SESSION",T_OBJECT_EX, offsetof(DefinesObject,NxAPIERR_NODATATYPE_FOR_SESSION),1,"NxAPIERR_NODATATYPE_FOR_SESSION"},
	{"NxAPIERR_NODATA_FOR_REPEXG",T_OBJECT_EX, offsetof(DefinesObject,NxAPIERR_NODATA_FOR_REPEXG),1,"NxAPIERR_NODATA_FOR_REPEXG"},
	{"NxAPIERR_ZEROED_DATA_FOR_SESSION",T_OBJECT_EX, offsetof(DefinesObject,NxAPIERR_ZEROED_DATA_FOR_SESSION),1,"NxAPIERR_ZEROED_DATA_FOR_SESSION"},
	{"NxAPIERR_SAVE_STATE_IN_PROGRESS",T_OBJECT_EX, offsetof(DefinesObject,NxAPIERR_SAVE_STATE_IN_PROGRESS),1,"NxAPIERR_SAVE_STATE_IN_PROGRESS"},
	{"NxAPIERR_NOT_SUPPORTED",T_OBJECT_EX, offsetof(DefinesObject,NxAPIERR_NOT_SUPPORTED),1,"NxAPIERR_NOT_SUPPORTED"},
	{"NxAPIERR_INITALLOC_ERROR",T_OBJECT_EX, offsetof(DefinesObject,NxAPIERR_INITALLOC_ERROR),1,"NxAPIERR_INITALLOC_ERROR"},
	{"NxAPIERR_NSODALLOC_ERROR",T_OBJECT_EX, offsetof(DefinesObject,NxAPIERR_NSODALLOC_ERROR),1,"NxAPIERR_NSODALLOC_ERROR"},
	{"NxAPIERR_UNSUPPORTED_API",T_OBJECT_EX, offsetof(DefinesObject,NxAPIERR_UNSUPPORTED_API),1,"NxAPIERR_UNSUPPORTED_API" },
	{"LULD_BND_EVT_NONE",T_OBJECT_EX, offsetof(DefinesObject,LULD_BND_EVT_NONE),1,"LULD_BND_EVT_NONE"},
	{"LULD_BND_EVT_OPENING",T_OBJECT_EX, offsetof(DefinesObject,LULD_BND_EVT_OPENING),1,"LULD_BND_EVT_OPENING"},
	{"LULD_BND_EVT_INTRADAY",T_OBJECT_EX, offsetof(DefinesObject,LULD_BND_EVT_INTRADAY),1,"LULD_BND_EVT_INTRADAY"},
	{"LULD_BND_EVT_RESTATED",T_OBJECT_EX, offsetof(DefinesObject,LULD_BND_EVT_RESTATED),1,"LULD_BND_EVT_RESTATED"},
	{"LULD_BND_EVT_SUSPENDED",T_OBJECT_EX, offsetof(DefinesObject,LULD_BND_EVT_SUSPENDED),1,"LULD_BND_EVT_SUSPENDED"},
	{"LULD_BND_EVT_REOPENING",T_OBJECT_EX, offsetof(DefinesObject,LULD_BND_EVT_REOPENING),1,"LULD_BND_EVT_REOPENING"},
	{"LULD_BND_EVT_OUTSIDE_HRS",T_OBJECT_EX, offsetof(DefinesObject,LULD_BND_EVT_OUTSIDE_HRS),1,"LULD_BND_EVT_OUTSIDE_HRS"},
	{ NULL }  /* Sentinel */
};


static PyTypeObject DefinesType = {
	PyVarObject_HEAD_INIT(NULL, 0)
"NxCore.Defines",	 /* tp_name */
	sizeof(DefinesObject), /* tp_basicsize */
	0,						 /* tp_itemsize */
	(destructor)Defines_dealloc,						 /* tp_dealloc */
	0,						 /* tp_print */
	0,						 /* tp_getattr */
	0,						 /* tp_setattr */
	0,						 /* tp_reserved */
	0,						 /* tp_repr */
	0,						 /* tp_as_number */
	0,						 /* tp_as_sequence */
	0,						 /* tp_as_mapping */
	0,						 /* tp_hash  */
	0,						 /* tp_call */
	0,						 /* tp_str */
	0,						 /* tp_getattro */
	0,						 /* tp_setattro */
	0,						 /* tp_as_buffer */
	Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE,		/* tp_flags */
"Defines Object",		   /* tp_doc */
	0,						 /* tp_traverse */
	0,						 /* tp_clear */
	0,						 /* tp_richcompare */
	0,						 /* tp_weaklistoffset */
	0,						 /* tp_iter */
	0,						 /* tp_iternext */
	0,						 /* tp_methods */
	Defines_members,		 /* tp_members */
	0,						 /* tp_getset */
	0,						 /* tp_base */
	0,						 /* tp_dict */
	0,						 /* tp_descr_get */
	0,						 /* tp_descr_set */
	0,						 /* tp_dictoffset */
	0,	  /* tp_init */
	0,						 /* tp_alloc */
	Defines_new,				 /* tp_new */
};

void AddDefineObjects(PyObject* m) {
	PyModule_AddIntConstant(m,"NxDATE_DST_UNKNOWN",0);
	PyModule_AddIntConstant(m,"NxDATE_DST_ON",1);
	PyModule_AddIntConstant(m,"NxDATE_DST_OFF",2);
	PyModule_AddIntConstant(m,"NxDATE_DST_ONTODAY",3);
	PyModule_AddIntConstant(m,"NxDATE_DST_OFFTODAY",4);
	PyModule_AddIntConstant(m,"NxDOW_SUNDAY",0);
	PyModule_AddIntConstant(m,"NxDOW_MONDAY",1);
	PyModule_AddIntConstant(m,"NxDOW_TUESDAY",2);
	PyModule_AddIntConstant(m,"NxDOW_WEDNESDAY",3);
	PyModule_AddIntConstant(m,"NxDOW_THURSDAY",4);
	PyModule_AddIntConstant(m,"NxDOW_FRIDAY",5);
	PyModule_AddIntConstant(m,"NxDOW_SATURDAY",6);
	PyModule_AddIntConstant(m,"NxCLOCK_NOCHANGE",0);
	PyModule_AddIntConstant(m,"NxCLOCK_CLOCK",1);
	PyModule_AddIntConstant(m,"NxCLOCK_SECOND",2);
	PyModule_AddIntConstant(m,"NxCLOCK_MINUTE",3);
	PyModule_AddIntConstant(m,"NxCLOCK_HOUR",4);
	PyModule_AddIntConstant(m,"NxCORESTATUS_RUNNING",0);
	PyModule_AddIntConstant(m,"NxCORESTATUS_INITIALIZING",1);
	PyModule_AddIntConstant(m,"NxCORESTATUS_COMPLETE",2);
	PyModule_AddIntConstant(m,"NxCORESTATUS_SYNCHRONIZING",3);
	PyModule_AddIntConstant(m,"NxCORESTATUS_ERROR",4);
	PyModule_AddIntConstant(m,"NxCORESTATUS_WAITFORCOREACCESS",5);
	PyModule_AddIntConstant(m,"NxCORESTATUS_RESTARTING_TAPE",6);
	PyModule_AddIntConstant(m,"NxCORESTATUS_LOADED_STATE",7);
	PyModule_AddIntConstant(m,"NxCORESTATUS_SAVING_STATE",8);
	PyModule_AddIntConstant(m,"NxCORESTATUS_SYMBOLSPIN",9);
	PyModule_AddIntConstant(m,"NxCORESTATUS_TAPEOPEN",10);
	PyModule_AddIntConstant(m,"NxCSRUNMODE_SRC_DISK_FILE",0);
	PyModule_AddIntConstant(m,"NxCSRUNMODE_SRC_ACCESS_FILE",1);
	PyModule_AddIntConstant(m,"NxCSRUNMODE_SRC_ACCESS_MEMORY",2);
	PyModule_AddIntConstant(m,"NxCSRUNMODE_SRC_ACCESS_MB_OLDEST",2);
	PyModule_AddIntConstant(m,"NxCSRUNMODE_SRC_ACCESS_MB_LOWER",3);
	PyModule_AddIntConstant(m,"NxCSRUNMODE_SRC_ACCESS_MB_UPPER",4);
	PyModule_AddIntConstant(m,"NxCSRUNMODE_SRC_ACCESS_MB_SECOND",5);
	PyModule_AddIntConstant(m,"NxCSRUNMODE_SRC_ACCESS_MB_CURRENT",6);
	PyModule_AddIntConstant(m,"NxCSSAVESTATE_CAPTURE",0);
	PyModule_AddIntConstant(m,"NxCSSAVESTATE_COMPLETE",1);
	PyModule_AddIntConstant(m,"NxCSSAVESTATE_ERR_CREATEFILE",-1);
	PyModule_AddIntConstant(m,"NxCSSAVESTATE_ERR_DISKSPACE",-2);
	PyModule_AddIntConstant(m,"NxCSSAVESTATE_ERR_MEMORY",-3);
	PyModule_AddIntConstant(m,"NxCSSYMBOLSPIN_STARTING",0);
	PyModule_AddIntConstant(m,"NxCSSYMBOLSPIN_COMPLETE",1);
	PyModule_AddIntConstant(m,"NxPERMID_REMOVE",0x00100000);
	PyModule_AddIntConstant(m,"NxQTE_NASDBIDTICK_NA",0);
	PyModule_AddIntConstant(m,"NxQTE_NASDBIDTICK_UP",1);
	PyModule_AddIntConstant(m,"NxQTE_NASDBIDTICK_DN",2);
	PyModule_AddIntConstant(m,"NxQTE_NASDBIDTICK_NO",3);
	PyModule_AddIntConstant(m,"NxQTE_REFRESH_REALTIME",0);
	PyModule_AddIntConstant(m,"NxQTE_REFRESH_SOURCE",1);
	PyModule_AddIntConstant(m,"NxQTE_REFRESH_MISMATCH",2);
	PyModule_AddIntConstant(m,"NxQTE_REFRESH_SYNCHRONIZE",3);
	PyModule_AddIntConstant(m,"NxBBOCHANGE_BIDEXG",0x01);
	PyModule_AddIntConstant(m,"NxBBOCHANGE_BIDPRICE",0x02);
	PyModule_AddIntConstant(m,"NxBBOCHANGE_BIDSIZE",0x04);
	PyModule_AddIntConstant(m,"NxBBOCHANGE_ASKEXG",0x10);
	PyModule_AddIntConstant(m,"NxBBOCHANGE_ASKPRICE",0x20);
	PyModule_AddIntConstant(m,"NxBBOCHANGE_ASKSIZE",0x40);
	PyModule_AddIntConstant(m,"NxMMT_UNKNOWN",0);
	PyModule_AddIntConstant(m,"NxMMT_REGULAR",1);
	PyModule_AddIntConstant(m,"NxMMT_PRIMARY",2);
	PyModule_AddIntConstant(m,"NxMMT_PASSIVE",3);
	PyModule_AddIntConstant(m,"NxMMQT_UNKNOWN",0);
	PyModule_AddIntConstant(m,"NxMMQT_REGULAR",1);
	PyModule_AddIntConstant(m,"NxMMQT_PASSIVE",2);
	PyModule_AddIntConstant(m,"NxMMQT_SYNDICATE",3);
	PyModule_AddIntConstant(m,"NxMMQT_PRESYNDICATE",4);
	PyModule_AddIntConstant(m,"NxMMQT_PENALTY",5);
	PyModule_AddIntConstant(m,"NxTPF_SETLAST",0x01);
	PyModule_AddIntConstant(m,"NxTPF_SETHIGH",0x02);
	PyModule_AddIntConstant(m,"NxTPF_SETLOW",0x04);
	PyModule_AddIntConstant(m,"NxTPF_SETOPEN",0x08);
	PyModule_AddIntConstant(m,"NxTPF_EXGINSERT",0x10);
	PyModule_AddIntConstant(m,"NxTPF_EXGCANCEL",0x20);
	PyModule_AddIntConstant(m,"NxTPF_SETTLEMENT",0x40);
	PyModule_AddIntConstant(m,"NxTCF_NOLAST",0x01);
	PyModule_AddIntConstant(m,"NxTCF_NOHIGH",0x02);
	PyModule_AddIntConstant(m,"NxTCF_NOLOW",0x04);
	PyModule_AddIntConstant(m,"NxTVT_INCRVOL",0);
	PyModule_AddIntConstant(m,"NxTVT_NONINCRVOL",1);
	PyModule_AddIntConstant(m,"NxTVT_TOTALVOL",2);
	PyModule_AddIntConstant(m,"NxTVT_TOTALVOLx100",3);
	PyModule_AddIntConstant(m,"NxRTA_SIGHL_EQ",0);
	PyModule_AddIntConstant(m,"NxRTA_SIGHL_LOWEST",1);
	PyModule_AddIntConstant(m,"NxRTA_SIGHL_LOW",2);
	PyModule_AddIntConstant(m,"NxRTA_SIGHL_HIGH",3);
	PyModule_AddIntConstant(m,"NxRTA_SIGHL_HIGHEST",4);
	PyModule_AddIntConstant(m,"NxRTA_QMTYPE_NONE",0);
	PyModule_AddIntConstant(m,"NxRTA_QMTYPE_BID",1);
	PyModule_AddIntConstant(m,"NxRTA_QMTYPE_ASK",2);
	PyModule_AddIntConstant(m,"NxRTA_QMTYPE_INSIDE",3);
	PyModule_AddIntConstant(m,"NxRTA_QMTYPE_BELOWBID",4);
	PyModule_AddIntConstant(m,"NxRTA_QMTYPE_ABOVEASK",5);
	PyModule_AddIntConstant(m,"NxRTA_QTEMATCHFLAG_OLDER",0x01);
	PyModule_AddIntConstant(m,"NxRTA_QTEMATCHFLAG_CROSSED",0x02);
	PyModule_AddIntConstant(m,"NxCFT_UNKNOWN",0);
	PyModule_AddIntConstant(m,"NxCFT_64BIT",1);
	PyModule_AddIntConstant(m,"NxCFT_32BIT",2);
	PyModule_AddIntConstant(m,"NxCFT_STRINGZ",3);
	PyModule_AddIntConstant(m,"NxCFT_DOUBLE",4);
	PyModule_AddIntConstant(m,"NxCFT_PRICE",5);
	PyModule_AddIntConstant(m,"NxCFT_DATE",6);
	PyModule_AddIntConstant(m,"NxCFT_TIME",7);
	PyModule_AddIntConstant(m,"NxCFT_NxSTRING",8);
	PyModule_AddIntConstant(m,"NxCFT_STRING_IDX",9);
	PyModule_AddIntConstant(m,"NxCFT_STRING_MAP",10);
	PyModule_AddIntConstant(m,"NxSS_ADD",0);
	PyModule_AddIntConstant(m,"NxSS_DEL",1);
	PyModule_AddIntConstant(m,"NxSS_MOD",2);
	PyModule_AddIntConstant(m,"NxSPIN_ALL_EXGS",(unsigned short)-1);
	PyModule_AddIntConstant(m,"NxSPIN_NON_OPTIONS",0);
	PyModule_AddIntConstant(m,"NxSPIN_OPTIONS",0x00000001);
	PyModule_AddIntConstant(m,"NxMSG_STATUS",0);
	PyModule_AddIntConstant(m,"NxMSG_EXGQUOTE",1);
	PyModule_AddIntConstant(m,"NxMSG_MMQUOTE",2);
	PyModule_AddIntConstant(m,"NxMSG_TRADE",3);
	PyModule_AddIntConstant(m,"NxMSG_CATEGORY",4);
	PyModule_AddIntConstant(m,"NxMSG_SYMBOLCHANGE",5);
	PyModule_AddIntConstant(m,"NxMSG_SYMBOLSPIN",6);
	PyModule_AddIntConstant(m,"NxSTATETYPE_OHLCTRADE",1);
	PyModule_AddIntConstant(m,"NxSTATETYPE_EXGQUOTES",2);
	PyModule_AddIntConstant(m,"NxSTATETYPE_MMQUOTES",3);
	PyModule_AddIntConstant(m,"NxLTF_SEARCH_LOCAL",0);
	PyModule_AddIntConstant(m,"NxLTF_SEARCH_NETWORK",0x00000001);
	PyModule_AddIntConstant(m,"NxLTF_SEARCH_REMOVEABLE",0x00000002);
	PyModule_AddIntConstant(m,"NxST_PERMID",2);
	PyModule_AddIntConstant(m,"NxST_EXCHANGE",3);
	PyModule_AddIntConstant(m,"NxST_TRADECONDITION",4);
	PyModule_AddIntConstant(m,"NxST_QUOTECONDITION",5);
	PyModule_AddIntConstant(m,"NxST_CATEGORY",6);
	PyModule_AddIntConstant(m,"NxST_HALTSTATUS",7);
	PyModule_AddIntConstant(m,"NxST_HALTREASONTYPE",8);
	PyModule_AddIntConstant(m,"NxST_OPENINDICATIONTYPE",9);
	PyModule_AddIntConstant(m,"NxST_ORDERIMBALANCETYPE",10);
	PyModule_AddIntConstant(m,"NxST_TRADEREPORTREASON",11);
	PyModule_AddIntConstant(m,"NxST_EXGCORRECTIONMAP",12);
	PyModule_AddIntConstant(m,"NxST_SYMBOLCHANGETYPE",13);
	PyModule_AddIntConstant(m,"NxST_OHLCFLAGS",14);
	PyModule_AddIntConstant(m,"NxST_EXDIVIDENDATTRIB",15);
	PyModule_AddIntConstant(m,"NxST_OPRAEXCHANGELIST",16);
	PyModule_AddIntConstant(m,"NxST_NASDBIDTICK",17);
	PyModule_AddIntConstant(m,"NxST_MARKETMAKERTYPE",18);
	PyModule_AddIntConstant(m,"NxST_MMQUOTETYPE",19);
	PyModule_AddIntConstant(m,"NxST_REFRESHTYPE",20);
	PyModule_AddIntConstant(m,"NxST_EXPIRATIONCYCLE",21);
	PyModule_AddIntConstant(m,"NxST_VOLUMETYPE",22);
	PyModule_AddIntConstant(m,"NxST_QTEMATCHTYPE",23);
	PyModule_AddIntConstant(m,"NxST_QTEMATCHFLAGS",24);
	PyModule_AddIntConstant(m,"NxST_SIGHIGHLOWTYPE",25);
	PyModule_AddIntConstant(m,"NxST_BBOCHANGEFLAGS",26);
	PyModule_AddIntConstant(m,"NxST_TRADECONDFLAGS",27);
	PyModule_AddIntConstant(m,"NxST_PRICEFLAGS",28);
	PyModule_AddIntConstant(m,"NxST_SETTLEFLAGMAP",29);
	PyModule_AddIntConstant(m,"NxST_SYMBOLFNCLSTATUSMAP",30);
	PyModule_AddIntConstant(m,"NxST_EQUITYCLASSIFICATIONS",31);
	PyModule_AddIntConstant(m,"NxST_SYMBOLTYPES",32);
	PyModule_AddIntConstant(m,"NxCF_EXCLUDE_QUOTES",0x00000001);
	PyModule_AddIntConstant(m,"NxCF_EXCLUDE_QUOTES2",0x00000002);
	PyModule_AddIntConstant(m,"NxCF_EXCLUDE_OPRA",0x00000004);
	PyModule_AddIntConstant(m,"NxCF_FAVOR_NBBO",0x00000008);
	PyModule_AddIntConstant(m,"NxCF_MEMORY_ADDRESS",0x04000000);
	PyModule_AddIntConstant(m,"NxCF_EXCLUDE_CRC_CHECK",0x08000000);
	PyModule_AddIntConstant(m,"NxSAVESTATE_GRADUALLY",0);
	PyModule_AddIntConstant(m,"NxSAVESTATE_ONEPASS",0x00000001);
	PyModule_AddIntConstant(m,"NxSAVESTATE_CANCEL",0x00000002);
	PyModule_AddIntConstant(m,"NxCALLBACKRETURN_CONTINUE",0);
	PyModule_AddIntConstant(m,"NxCALLBACKRETURN_STOP",1);
	PyModule_AddIntConstant(m,"NxCALLBACKRETURN_RESTART",2);
	PyModule_AddIntConstant(m,"NxAPIERR_NO_ERROR",0);
	PyModule_AddIntConstant(m,"NxAPIERR_USER_STOPPED",1);
	PyModule_AddIntConstant(m,"NxAPIERR_NOT_CALLBACK_THREAD",-1);
	PyModule_AddIntConstant(m,"NxAPIERR_BAD_PARAMETERS",-2);
	PyModule_AddIntConstant(m,"NxAPIERR_EXCEPTION",-3);
	PyModule_AddIntConstant(m,"NxAPIERR_OPEN_TAPE_FILE_FAILED",-4);
	PyModule_AddIntConstant(m,"NxAPIERR_INITIALIZE_MEMORY_FAILED",-5);
	PyModule_AddIntConstant(m,"NxAPIERR_NOLISTED_EXG",-6);
	PyModule_AddIntConstant(m,"NxAPIERR_NOSYMBOLS_FOR_LSTEXG",-7);
	PyModule_AddIntConstant(m,"NxAPIERR_NOSESSION_FOR_SYMBOL",-8);
	PyModule_AddIntConstant(m,"NxAPIERR_NODATATYPE_FOR_SESSION",-9);
	PyModule_AddIntConstant(m,"NxAPIERR_NODATA_FOR_REPEXG",-10);
	PyModule_AddIntConstant(m,"NxAPIERR_ZEROED_DATA_FOR_SESSION",-11);
	PyModule_AddIntConstant(m,"NxAPIERR_SAVE_STATE_IN_PROGRESS",-12);
	PyModule_AddIntConstant(m,"NxAPIERR_NOT_SUPPORTED",-13);
	PyModule_AddIntConstant(m,"NxAPIERR_INITALLOC_ERROR",-14);
	PyModule_AddIntConstant(m,"NxAPIERR_NSODALLOC_ERROR",-15);
	PyModule_AddIntConstant(m,"LULD_BND_EVT_NONE",0x00);
	PyModule_AddIntConstant(m,"LULD_BND_EVT_OPENING",0x01);
	PyModule_AddIntConstant(m,"LULD_BND_EVT_INTRADAY",0x02);
	PyModule_AddIntConstant(m,"LULD_BND_EVT_RESTATED",0x03);
	PyModule_AddIntConstant(m,"LULD_BND_EVT_SUSPENDED",0x04);
	PyModule_AddIntConstant(m,"LULD_BND_EVT_REOPENING",0x05);
	PyModule_AddIntConstant(m,"LULD_BND_EVT_OUTSIDE_HRS",0x06);

}