from setuptools import setup, Extension

NxCore_module = Extension('NxCore', sources = ['NxCorePython.cpp'], extra_compile_args = ["-std=c++17"])

setup(
    name='NxCore',
	version="1.0.0",
    description='NxCore Python Wrapper',
    ext_modules=[NxCore_module],
	license="BSD 3-Clause",
	license_files = ('LICENSE',),
	py_modules = [],
)